@@ -5,6 +5,7 @@ namespace
     Arg::LongOption longOptions[] =
     {
         {"arg",                 'a'},
+        {"called-by",           'c'},
         {"full-symbol",         'f'},
         {"help",                'h'},
         {"no-xref",             'X'},
@@ -26,8 +27,8 @@ namespace
 int main(int argc, char **argv)
 try
 {
-    Arg &arg = Arg::initialize("a:fhor:R:st:vxX", longOptions, longEnd, 
-                                                  argc, argv);
+    Arg &arg = Arg::initialize("a:c:fhor:R:st:vxX", longOptions, longEnd, 
+                                                    argc, argv);
     arg.versionHelp(usage, version, 1);
 
     ObjDump odump;
@@ -44,6 +45,7 @@ try
 
     storage.xref();         // maybe show the cross-reference info
     storage.tree();         // maybe show the call-tree
+    storage.calledBy();     // maybe show the called-by hierarchy
 }
 catch (std::exception const &e)
 {
