@@ -30,7 +30,7 @@ void Store::checkGlobals(IdxIter &begin, IdxIter &end)
         }                                       // the source's function name
     }
 
-    find_if(iter + 1, end,                      // maybe find such a name
+    iter = find_if(iter + 1, end,               // maybe find such a name
         [&](size_t idx)
         {                                       // not here...
             if (d_xrefVector[idx].symbol().find(name) == string::npos)
