@@ -17,7 +17,7 @@ void Store::insert(ostream &out, string const &name, bool doSelect) const
                         iter, end, 
                         [&](size_t idx)
                         {
-                            return string(d_xrefData[idx].name()).find(name) 
+                            return string(d_xrefVector[idx].name()).find(name) 
                                     == 0;
                         }
                     )
@@ -26,14 +26,14 @@ void Store::insert(ostream &out, string const &name, bool doSelect) const
                         iter, end, 
                         [&](size_t idx)
                         {
-                            return namePattern << d_xrefData[idx].symbol();
+                            return namePattern << d_xrefVector[idx].symbol();
                         }
                     );
 
         if (iter == end)
             break;
 
-        insertDefined(*iter, out, d_xrefData);
+        insertDefined(*iter, out, d_xrefVector);
         ++iter;
     }
 }
