@@ -5,29 +5,29 @@
 
 void Store::undefined(std::string const &symbol)
 {
-    // find 'symbol' in d_xrefData. 
+    // find 'symbol' in d_xrefVector. 
     // If not yet available add it to xrefData.
     // Determine the symbol's index in xrefData
     // The function currently handled has a currentIdx and from that index
     // the current *UND* symbol is called.
                 
     auto iter = find_if(
-                    d_xrefData.begin(), d_xrefData.end(),
+                    d_xrefVector.begin(), d_xrefVector.end(),
                     [&](XrefData const &xrefData)
                     {
                         return xrefData.hasSymbol(symbol);
                     }
                 );
 
-    size_t index = iter - d_xrefData.begin();   // index of this symbol
+    size_t index = iter - d_xrefVector.begin();   // index of this symbol
 
-    if (iter == d_xrefData.end())               // symbol not yet defined
+    if (iter == d_xrefVector.end())               // symbol not yet defined
     {
-        index = d_xrefData.size();
-        d_xrefData.push_back(XrefData{ symbol });   // define the symbol
+        index = d_xrefVector.size();
+        d_xrefVector.push_back(XrefData{ symbol });   // define the symbol
     }
 
-    d_xrefData[index].calledFrom(d_currentIdx);
+    d_xrefVector[index].calledFrom(d_currentIdx);
 }
 
 
