@@ -27,7 +27,7 @@ class XrefData
     bool d_fullSymbol;
 
     public:
-        typedef std::vector<XrefData>   XrefVector;
+        using XrefVector = std::vector<XrefData>;
 
         XrefData();
         XrefData(std::string const &sourceFile, 
@@ -41,15 +41,20 @@ class XrefData
         bool isDefined(std::string const &symbol) const;
         bool hasSymbol(std::string const &symbol) const;
     
-        void calledFrom(size_t currentIdx);
+        void calledFrom(size_t currentIdx); // the current function is called
+                                            // from the function at
+                                            // 'currentIdx', which is an index
+                                            // in Store::d_xrefVector
+
 
         void defined(std::ostream &out) const;
-        std::string const &symbol() const;// returns d_cooked
-        char const *name() const;         // returns d_cooked[d_nameIndex] 
 
-        std::string const &sourceFile() const;
-
-        std::vector<size_t> const &usedBy() const;
+        std::string const &fullName() const;    // returns d_refName    //  .h
+        std::string const &symbol() const;// returns d_cooked           //  .h
+        char const *name() const;         // returns d_cooked[d_nameIndex]  .h
+        std::string const &sourceFile() const;                          //  .h
+        std::vector<size_t> const &usedBy() const;                      //  .h
+        bool isFunction() const;                                        //  .h
 
     private:
         void ctor();
@@ -64,7 +69,7 @@ class XrefData
         size_t eraseParam(size_t begin, size_t len);
 };
 
-typedef XrefData::XrefVector    XrefVector;
+using  XrefVector = XrefData::XrefVector;
 
 inline std::vector<size_t> const &XrefData::usedBy() const
 {
@@ -86,4 +91,14 @@ inline  std::string const &XrefData::symbol() const
     return d_cooked;
 }
 
+inline  std::string const &XrefData::fullName() const
+{
+    return d_refName;
+}
+
+inline  bool XrefData::isFunction() const
+{
+    return d_isFunction;
+}
+
 #endif
